==> blancoStringGroup-0.1.1-src.zip: blancoStringGroup/blanco/main/blanco/sample/stringgroup/SampleStringGroup.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.sample.stringgroup;

/**
 * O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
 */
public class SampleStringGroup {
    /**
     * No.1 :At@xbg̕`B
     */
    public static final int ABCDEFG = 1;

    /**
     * No.2 :Sp̕`B
     */
    public static final int AIUEO = 2;

    /**
     * No.3 :VONI[gWJ邱Ƃ̊mFB
     */
    public static final int QUOTE = 3;

    /**
     * No.4 :_uNI[gWJ邱Ƃ̊mFB
     */
    public static final int DOUBLE_QUOTE = 4;

    /**
     * No.5 :obNXbVWJ邱Ƃ̊mFB
     */
    public static final int BACK_SLASH = 5;

    /**
     * No.7
     */
    public static final int WITHOUT_DESC = 7;

    /**
     * No.8 :r̋󔒂K؂ɏ邱Ƃ̊mFB
     */
    public static final int TEST_SPACE = 8;

    /**
     * `BO[vȊO̕܂͒萔`̂́B
     */
    public static final int NOT_DEFINED = -1;

    /**
     * O[vɊ܂܂镶ł邩ǂ𔻒肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean match(final String argCheck) {
        // No.1
        // :At@xbg̕`B
        if ("ABCDEFG".equals(argCheck)) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if ("".equals(argCheck)) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ("'".equals(argCheck)) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ("\"".equals(argCheck)) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ("\\".equals(argCheck)) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if ("STRING ONLY".equals(argCheck)) {
            return true;
        }
        // No.7
        if ("ȗ".equals(argCheck)) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ("ABC DEF".equals(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean matchIgnoreCase(final String argCheck) {
        // No.1
        // :At@xbg̕`B
        if ("ABCDEFG".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if ("".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ("'".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ("\"".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ("\\".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if ("STRING ONLY".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.7
        if ("ȗ".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ("ABC DEF".equalsIgnoreCase(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * 񂩂萔ɕϊ܂B
     *
     * 萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B
     *
     * @param argCheck ϊsB
     * @return 萔ɕϊ̒lB
     */
    public int convertToInt(final String argCheck) {
        // No.1
        // :At@xbg̕`B
        if ("ABCDEFG".equals(argCheck)) {
            return ABCDEFG;
        }
        // No.2
        // :Sp̕`B
        if ("".equals(argCheck)) {
            return AIUEO;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ("'".equals(argCheck)) {
            return QUOTE;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ("\"".equals(argCheck)) {
            return DOUBLE_QUOTE;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ("\\".equals(argCheck)) {
            return BACK_SLASH;
        }
        // No.7
        if ("ȗ".equals(argCheck)) {
            return WITHOUT_DESC;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ("ABC DEF".equals(argCheck)) {
            return TEST_SPACE;
        }

        // Y萔܂łB
        return NOT_DEFINED;
    }
}

==> blancoStringGroup-0.1.5-src.zip: blancoStringGroup/blanco/main/blanco/sample/stringgroup/SampleStringGroup.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.sample.stringgroup;

/**
 * O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
 */
public class SampleStringGroup {
    /**
     * No.1 :At@xbg̕`B
     */
    public static final int ABCDEFG = 1;

    /**
     * No.2 :Sp̕`B
     */
    public static final int AIUEO = 2;

    /**
     * No.3 :VONI[gWJ邱Ƃ̊mFB
     */
    public static final int QUOTE = 3;

    /**
     * No.4 :_uNI[gWJ邱Ƃ̊mFB
     */
    public static final int DOUBLE_QUOTE = 4;

    /**
     * No.5 :obNXbVWJ邱Ƃ̊mFB
     */
    public static final int BACK_SLASH = 5;

    /**
     * No.7
     */
    public static final int WITHOUT_DESC = 7;

    /**
     * No.8 :r̋󔒂K؂ɏ邱Ƃ̊mFB
     */
    public static final int TEST_SPACE = 8;

    /**
     * No.9 :~}[NB
     */
    public static final int BATU = 9;

    /**
     * `BO[vȊO̕܂͒萔`̂́B
     */
    public static final int NOT_DEFINED = -1;

    /**
     * O[vɊ܂܂镶ł邩ǂ𔻒肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean match(final String argCheck) {
        // No.1
        // :At@xbg̕`B
        if ("ABCDEFG".equals(argCheck)) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if ("".equals(argCheck)) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ("'".equals(argCheck)) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ("\"".equals(argCheck)) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ("\\".equals(argCheck)) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if ("STRING ONLY".equals(argCheck)) {
            return true;
        }
        // No.7
        if ("ȗ".equals(argCheck)) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ("ABC DEF".equals(argCheck)) {
            return true;
        }
        // No.9
        // :~}[NB
        if ("~".equals(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean matchIgnoreCase(final String argCheck) {
        // No.1
        // :At@xbg̕`B
        if ("ABCDEFG".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if ("".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ("'".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ("\"".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ("\\".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if ("STRING ONLY".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.7
        if ("ȗ".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ("ABC DEF".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.9
        // :~}[NB
        if ("~".equalsIgnoreCase(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * 񂩂萔ɕϊ܂B
     *
     * 萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B
     *
     * @param argCheck ϊsB
     * @return 萔ɕϊ̒lB
     */
    public int convertToInt(final String argCheck) {
        // No.1
        // :At@xbg̕`B
        if ("ABCDEFG".equals(argCheck)) {
            return ABCDEFG;
        }
        // No.2
        // :Sp̕`B
        if ("".equals(argCheck)) {
            return AIUEO;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ("'".equals(argCheck)) {
            return QUOTE;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ("\"".equals(argCheck)) {
            return DOUBLE_QUOTE;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ("\\".equals(argCheck)) {
            return BACK_SLASH;
        }
        // No.7
        if ("ȗ".equals(argCheck)) {
            return WITHOUT_DESC;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ("ABC DEF".equals(argCheck)) {
            return TEST_SPACE;
        }
        // No.9
        // :~}[NB
        if ("~".equals(argCheck)) {
            return BATU;
        }

        // Y萔܂łB
        return NOT_DEFINED;
    }

    /**
     * 萔當ɕϊ܂B
     *
     * 萔ƑΉÂɕϊ܂B
     *
     * @param argCheck ϊs萔B
     * @return ɕϊ̒lBNOT_DEFINED̏ꍇɂ͒0̕B
     */
    public String convertToString(final int argCheck) {
        // No.1
        // :At@xbg̕`B
        if (argCheck == ABCDEFG) {
            return "ABCDEFG";
        }
        // No.2
        // :Sp̕`B
        if (argCheck == AIUEO) {
            return "";
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if (argCheck == QUOTE) {
            return "'";
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if (argCheck == DOUBLE_QUOTE) {
            return "\"";
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if (argCheck == BACK_SLASH) {
            return "\\";
        }
        // No.7
        if (argCheck == WITHOUT_DESC) {
            return "ȗ";
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if (argCheck == TEST_SPACE) {
            return "ABC DEF";
        }
        // No.9
        // :~}[NB
        if (argCheck == BATU) {
            return "~";
        }
        // `B
        if (argCheck == NOT_DEFINED) {
            return "";
        }

        // ɂY܂łB
        throw new IllegalArgumentException("^ꂽl(" + argCheck + ")͕O[v[Sample]ł͒`ȂlłB");
    }
}
